.. _user:

################
NumPy user guide
################

This guide is an overview and explains the important features;
details are found in :ref:`reference`.

.. toctree::
   :maxdepth: 1

   whatisnumpy
   Installation <https://numpy.org/install/>
   quickstart
   absolute_beginners
   basics
   misc
   numpy-for-matlab-users
   building
   c-info
   NumPy Tutorials <https://numpy.org/numpy-tutorials/features.html>
   howtos_index
   depending_on_numpy


.. Links to these files are placed directly in the top-level html
   (doc/source/_templates/indexcontent.html, which appears for the URLs
   numpy.org/devdocs and numpy.org/doc/XX) and are not in any toctree, so
   we include them here to avoid a "WARNING: document isn't included in any
   toctree" message

.. toctree::
   :hidden:

   ../f2py/index
   ../glossary
   ../dev/underthehood
   ../bugs
   ../release
   ../license
